==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/yrtsubscription/yrtsubscription/check/DefaultValue.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.check;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.check.value.Stop;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of value.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultValue extends InnerModelObject implements Value {
    protected Stop stop;

    @Override
    public Stop stop() {
        return stop;
    }

    @Override
    public void stop(Stop stop) {
        this.stop = stop;
    }

    @Override
    public int hashCode() {
        return Objects.hash(stop);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultValue) {
            DefaultValue other = (DefaultValue) obj;
            return
                Objects.equals(stop, other.stop);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("stop=" + stop)
            .toString();
    }


    /**
     * Creates an instance of defaultValue.
     */
    public DefaultValue() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtsubscription/yrtsubscription/check/DefaultValue.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.check;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.check.value.Stop;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of value.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultValue extends InnerModelObject implements Value {
    protected Stop stop;

    @Override
    public Stop stop() {
        return stop;
    }

    @Override
    public void stop(Stop stop) {
        this.stop = stop;
    }

    @Override
    public int hashCode() {
        return Objects.hash(stop);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultValue) {
            DefaultValue other = (DefaultValue) obj;
            return
                Objects.deepEquals(stop, other.stop);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("stop=" + stop)
            .toString();
    }


    /**
     * Creates an instance of defaultValue.
     */
    public DefaultValue() {
    }

}
